==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/TunnelFlapPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.mojang.datafixers.util.Pair;
import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.content.logistics.tunnel.BeltTunnelBlockEntity;
import io.netty.buffer.ByteBuf;
import org.apache.logging.log4j.util.TriConsumer;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record TunnelFlapPacket(class_2338 pos, List<Pair<class_2350, Boolean>> flaps) implements S2CPacket {
    public static final class_9139<ByteBuf, TunnelFlapPacket> CODEC = class_9139.method_56435(
        class_2338.field_48404,
        TunnelFlapPacket::pos,
        CatnipStreamCodecBuilders.list(CatnipStreamCodecBuilders.pair(class_2350.field_48450, class_9135.field_48547)),
        TunnelFlapPacket::flaps,
        TunnelFlapPacket::new
    );

    public TunnelFlapPacket(BeltTunnelBlockEntity blockEntity, List<Pair<class_2350, Boolean>> flaps) {
        this(blockEntity.method_11016(), new ArrayList<>(flaps));
    }

    @Override
    public <T> TriConsumer<AllClientHandle<T>, T, TunnelFlapPacket> callback() {
        return AllClientHandle::onTunnelFlap;
    }

    @Override
    public class_9145<TunnelFlapPacket> method_65080() {
        return AllPackets.TUNNEL_FLAP;
    }
}

==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/TunnelFlapPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.mojang.datafixers.util.Pair;
import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.content.logistics.tunnel.BeltTunnelBlockEntity;
import io.netty.buffer.ByteBuf;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record TunnelFlapPacket(class_2338 pos, List<Pair<class_2350, Boolean>> flaps) implements class_2596<class_2602> {
    public static final class_9139<ByteBuf, TunnelFlapPacket> CODEC = class_9139.method_56435(
        class_2338.field_48404,
        TunnelFlapPacket::pos,
        CatnipStreamCodecBuilders.list(CatnipStreamCodecBuilders.pair(class_2350.field_48450, class_9135.field_48547)),
        TunnelFlapPacket::flaps,
        TunnelFlapPacket::new
    );

    public TunnelFlapPacket(BeltTunnelBlockEntity blockEntity, List<Pair<class_2350, Boolean>> flaps) {
        this(blockEntity.method_11016(), new ArrayList<>(flaps));
    }

    @Override
    public void apply(class_2602 listener) {
        AllClientHandle.INSTANCE.onTunnelFlap(this);
    }

    @Override
    public class_9145<TunnelFlapPacket> method_65080() {
        return AllPackets.TUNNEL_FLAP;
    }
}
